@@ -2,43 +2,72 @@
 import all wrapper function
 """
 
+# callback
+from je_auto_control.utils.callback.callback_function_executor import \
+    callback_executor
 # Critical
 from je_auto_control.utils.critical_exit.critcal_exit import CriticalExit
-from je_auto_control.utils.exception.exceptions import AutoControlActionException
-from je_auto_control.utils.exception.exceptions import AutoControlActionNullException
-from je_auto_control.utils.exception.exceptions import AutoControlCantFindKeyException
+from je_auto_control.utils.exception.exceptions import \
+    AutoControlActionException
+from je_auto_control.utils.exception.exceptions import \
+    AutoControlActionNullException
+from je_auto_control.utils.exception.exceptions import \
+    AutoControlCantFindKeyException
 # Exception
 from je_auto_control.utils.exception.exceptions import AutoControlException
-from je_auto_control.utils.exception.exceptions import AutoControlJsonActionException
-from je_auto_control.utils.exception.exceptions import AutoControlKeyboardException
-from je_auto_control.utils.exception.exceptions import AutoControlMouseException
-from je_auto_control.utils.exception.exceptions import AutoControlRecordException
-from je_auto_control.utils.exception.exceptions import AutoControlScreenException
+from je_auto_control.utils.exception.exceptions import \
+    AutoControlJsonActionException
+from je_auto_control.utils.exception.exceptions import \
+    AutoControlKeyboardException
+from je_auto_control.utils.exception.exceptions import \
+    AutoControlMouseException
+from je_auto_control.utils.exception.exceptions import \
+    AutoControlRecordException
+from je_auto_control.utils.exception.exceptions import \
+    AutoControlScreenException
 from je_auto_control.utils.exception.exceptions import ImageNotFoundException
-from je_auto_control.utils.executor.action_executor import add_command_to_executor
+from je_auto_control.utils.executor.action_executor import \
+    add_command_to_executor
 # executor
 from je_auto_control.utils.executor.action_executor import execute_action
 from je_auto_control.utils.executor.action_executor import execute_files
 from je_auto_control.utils.executor.action_executor import executor
-from je_auto_control.utils.file_process.create_project_structure import create_template_dir
+from je_auto_control.utils.file_process.create_project_structure import \
+    create_template_dir
 # file process
-from je_auto_control.utils.file_process.get_dir_file_list import get_dir_files_as_list
+from je_auto_control.utils.file_process.get_dir_file_list import \
+    get_dir_files_as_list
 # html report
-from je_auto_control.utils.generate_report.generate_html_report import generate_html
-from je_auto_control.utils.generate_report.generate_html_report import generate_html_report
+from je_auto_control.utils.generate_report.generate_html_report import \
+    generate_html
+from je_auto_control.utils.generate_report.generate_html_report import \
+    generate_html_report
+from je_auto_control.utils.generate_report.generate_json_report import \
+    generate_json
+from je_auto_control.utils.generate_report.generate_json_report import \
+    generate_json_report
+# xml
+from je_auto_control.utils.generate_report.generate_xml_report import \
+    generate_xml
+from je_auto_control.utils.generate_report.generate_xml_report import \
+    generate_xml_report
 # utils image
 from je_auto_control.utils.image.screenshot import pil_screenshot
 # json
 from je_auto_control.utils.json.json_file import read_action_json
 from je_auto_control.utils.json.json_file import write_action_json
-from je_auto_control.utils.generate_report.generate_json_report import generate_json
-from je_auto_control.utils.generate_report.generate_json_report import generate_json_report
+# package manager
+from je_auto_control.utils.package_manager.package_manager_class import \
+    package_manager
 # socket server
-from je_auto_control.utils.socket_server.auto_control_socket_server import start_autocontrol_socket_server
+from je_auto_control.utils.socket_server.auto_control_socket_server import \
+    start_autocontrol_socket_server
 # test record
-from je_auto_control.utils.test_record.record_test_class import test_record_instance
+from je_auto_control.utils.test_record.record_test_class import \
+    test_record_instance
 # timeout
-from je_auto_control.utils.timeout.multiprocess_timeout import multiprocess_timeout
+from je_auto_control.utils.timeout.multiprocess_timeout import \
+    multiprocess_timeout
 # import image
 from je_auto_control.wrapper.auto_control_image import locate_all_image
 from je_auto_control.wrapper.auto_control_image import locate_and_click
@@ -51,6 +80,8 @@ from je_auto_control.wrapper.auto_control_keyboard import press_key
 from je_auto_control.wrapper.auto_control_keyboard import release_key
 from je_auto_control.wrapper.auto_control_keyboard import type_key
 from je_auto_control.wrapper.auto_control_keyboard import write
+from je_auto_control.wrapper.auto_control_keyboard import get_keys_table
+from je_auto_control.wrapper.auto_control_keyboard import get_special_table
 # import mouse
 from je_auto_control.wrapper.auto_control_mouse import click_mouse
 from je_auto_control.wrapper.auto_control_mouse import mouse_table
@@ -66,13 +97,6 @@ from je_auto_control.wrapper.auto_control_record import stop_record
 from je_auto_control.wrapper.auto_control_screen import screenshot
 # import screen
 from je_auto_control.wrapper.auto_control_screen import size
-# xml
-from je_auto_control.utils.generate_report.generate_xml_report import generate_xml
-from je_auto_control.utils.generate_report.generate_xml_report import generate_xml_report
-# callback
-from je_auto_control.utils.callback.callback_function_executor import callback_executor
-# package manager
-from je_auto_control.utils.package_manager.package_manager_class import package_manager
 
 __all__ = [
     "click_mouse", "mouse_table", "position", "press_mouse", "release_mouse",
@@ -96,6 +120,8 @@ __all__ = [
     "generate_html", "generate_html_report",
     "generate_json", "generate_json_report",
     "generate_xml", "generate_xml_report",
-    "get_dir_files_as_list", "create_template_dir", "start_autocontrol_socket_server",
-    "callback_executor", "package_manager"
+    "get_dir_files_as_list", "create_template_dir",
+    "start_autocontrol_socket_server",
+    "callback_executor", "package_manager",
+    "get_special_table"
 ]
