@@ -17,15 +17,15 @@ class CriticalExit(Thread):
         :param default_daemon bool thread setDaemon
         """
         super().__init__()
-        self.setDaemon(default_daemon)
-        self._exit_check_key = keys_table.get("f7")
+        self.daemon = default_daemon
+        self._exit_check_key: int = keys_table.get("f7")
 
     def set_critical_key(self, keycode: [int, str] = None) -> None:
         """
         set interrupt key
         :param keycode interrupt key
         """
-        if type(keycode) is int:
+        if isinstance(keycode, int):
             self._exit_check_key = keycode
         else:
             self._exit_check_key = keys_table.get(keycode)
