@@ -2,8 +2,8 @@ import sys
 from typing import List, Union
 
 
-from je_auto_control.utils.exception.exception_tag import cant_find_image
-from je_auto_control.utils.exception.exception_tag import find_image_error_variable
+from je_auto_control.utils.exception.exception_tags import cant_find_image
+from je_auto_control.utils.exception.exception_tags import find_image_error_variable
 from je_auto_control.utils.exception.exceptions import ImageNotFoundException
 from je_auto_control.utils.image import template_detection
 from je_auto_control.utils.image.screenshot import pil_screenshot
@@ -100,7 +100,7 @@ def screenshot(file_path: str = None, region: list = None) -> List[Union[int, in
     """
     use to get now screen image return image
     :param file_path save screenshot path (None is no save)
-    :param region screenshot region (screenshot region on screen)
+    :param region screenshot screen_region (screenshot screen_region on screen)
     """
     param = locals()
     try:
